@@ -1,3 +1,15 @@
+//! prepare-commit-msg binary
+#![warn(
+    rust_2018_idioms,
+    unused,
+    rust_2021_compatibility,
+    nonstandard_style,
+    future_incompatible,
+    missing_copy_implementations,
+    missing_debug_implementations,
+    missing_docs
+)]
+
 use std::{
     convert::TryFrom,
     env,
@@ -23,8 +35,6 @@ use tinytemplate::TinyTemplate;
 
 use crate::{cli::app, errors::MitPrepareCommitMessageError::MissingCommitFilePath};
 
-extern crate tinytemplate;
-
 mod cli;
 mod errors;
 
@@ -94,7 +104,12 @@ fn append_coauthors_to_commit_message(
 
     let trailers = authors
         .iter()
-        .map(|x| Trailer::new("Co-authored-by", &format!("{} <{}>", x.name(), x.email())))
+        .map(|x| {
+            Trailer::new(
+                "Co-authored-by".to_string(),
+                format!("{} <{}>", x.name(), x.email()),
+            )
+        })
         .collect::<Vec<_>>();
 
     for trailer in trailers {
@@ -132,7 +147,7 @@ fn append_relate_to_trailer_to_commit_message(
             },
         )
         .into_diagnostic()?;
-    let trailer = Trailer::new("Relates-to", &value);
+    let trailer = Trailer::new("Relates-to".to_string(), value);
     add_trailer_if_not_existing(commit_message_path, &commit_message, &trailer)?;
 
     Ok(())
@@ -140,8 +155,8 @@ fn append_relate_to_trailer_to_commit_message(
 
 fn add_trailer_if_not_existing(
     commit_message_path: PathBuf,
-    commit_message: &CommitMessage,
-    trailer: &Trailer,
+    commit_message: &CommitMessage<'_>,
+    trailer: &Trailer<'_>,
 ) -> Result<()> {
     if commit_message
         .get_trailers()
